==> ssp-center-api-0.5.41-20190729.021326-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ProblemMenusDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * 常见问题菜单内容表
 */
public class ProblemMenusDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     *
     */
    private Long              id;

    /**
     * 问题类别
     */
    private String            problemCategory;

    /**
     * 问题类别排序序号
     */
    private Integer           sortCategory;

    /**
     * 帮助标题
     */
    private String            title;

    /**
     * 标题排序序号
     */
    private Integer           sortTitle;

    /**
     * 帮助内容
     */
    private String            content;

    /**
     * 创建人
     */
    private String            creater;

    /**
     * 创建时间
     */
    private Date              gmtCreate;

    /**
     * 修改时间
     */
    private Date              gmtModified;

    /**
     * 最新保存时间
     */
    private String            newSaveDate;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setProblemCategory(String problemCategory) {
        this.problemCategory = problemCategory;
    }

    public String getProblemCategory() {
        return problemCategory;
    }

    public void setSortCategory(Integer sortCategory) {
        this.sortCategory = sortCategory;
    }

    public Integer getSortCategory() {
        return sortCategory;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTitle() {
        return title;
    }

    public void setSortTitle(Integer sortTitle) {
        this.sortTitle = sortTitle;
    }

    public Integer getSortTitle() {
        return sortTitle;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getContent() {
        return content;
    }

    public void setCreater(String creater) {
        this.creater = creater;
    }

    public String getCreater() {
        return creater;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getNewSaveDate() {
        return newSaveDate;
    }

    public void setNewSaveDate(String newSaveDate) {
        this.newSaveDate = newSaveDate;
    }
}

==> ssp-center-api-0.6.03-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ProblemMenusDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * 常见问题菜单内容表
 */
public class ProblemMenusDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     *
     */
    private Long              id;

    /**
     * 问题类别
     */
    private String            problemCategory;

    /**
     * 问题类别排序序号
     */
    private Integer           sortCategory;

    /**
     * 帮助标题
     */
    private String            title;

    /**
     * 标题排序序号
     */
    private Integer           sortTitle;

    /**
     * 帮助内容
     */
    private String            content;

    /**
     * 是否为Top10：1-否 2-是
     */
    private Integer           isTopten;

    /**
     * 是否同步到微信服务号：1-否 2-是
     */
    private Integer           isSync;

    /**
     * 创建人
     */
    private String            creater;

    /**
     * 创建时间
     */
    private Date              gmtCreate;

    /**
     * 修改时间
     */
    private Date              gmtModified;

    /**
     * 最新保存时间
     */
    private String            newSaveDate;

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setProblemCategory(String problemCategory) {
        this.problemCategory = problemCategory;
    }

    public String getProblemCategory() {
        return problemCategory;
    }

    public void setSortCategory(Integer sortCategory) {
        this.sortCategory = sortCategory;
    }

    public Integer getSortCategory() {
        return sortCategory;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getTitle() {
        return title;
    }

    public void setSortTitle(Integer sortTitle) {
        this.sortTitle = sortTitle;
    }

    public Integer getSortTitle() {
        return sortTitle;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getContent() {
        return content;
    }

    public void setCreater(String creater) {
        this.creater = creater;
    }

    public String getCreater() {
        return creater;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getNewSaveDate() {
        return newSaveDate;
    }

    public void setNewSaveDate(String newSaveDate) {
        this.newSaveDate = newSaveDate;
    }

    public Integer getIsTopten() {
        return isTopten;
    }

    public void setIsTopten(Integer isTopten) {
        this.isTopten = isTopten;
    }

    public Integer getIsSync() {
        return isSync;
    }

    public void setIsSync(Integer isSync) {
        this.isSync = isSync;
    }
}
